Index: src/CodeGen/CodeGenerator.cpp
===================================================================
--- src/CodeGen/CodeGenerator.cpp	(revision 9b9d3f921760d08a71a28dd72e9a8d05d3ffea91)
+++ src/CodeGen/CodeGenerator.cpp	(revision d96f7c4f1e2b7dfb521e83969e9704b7e12505da)
@@ -9,7 +9,7 @@
 // Author           : Andrew Beach
 // Created On       : Tue Oct 17 15:54:00 2023
-// Last Modified By : Andrew Beach
-// Last Modified On : Wed Oct 25 18:28:00 2023
-// Update Count     : 0
+// Last Modified By : Peter A. Buhr
+// Last Modified On : Fri Jan 17 14:19:22 2025
+// Update Count     : 1
 //
 
@@ -1092,11 +1092,11 @@
 	case ast::BranchStmt::FallThrough:
 	case ast::BranchStmt::FallThroughDefault:
-		assertf( !options.genC, "fallthru should not reach code generation." );
-		output << "fallthru";
+		assertf( !options.genC, "fallthrough should not reach code generation." );
+		output << "fallthrough";
 		break;
 	default:
 		assertf( false, "Bad BranchStmt value." );
 	}
 	// Print branch target for labelled break/continue/fallthru in debug mode.
 	if ( !options.genC && stmt->kind != ast::BranchStmt::Goto ) {
 		if ( !stmt->target.empty() ) {
@@ -1092,11 +1092,11 @@
 		assertf( false, "Bad BranchStmt value." );
 	}
-	// Print branch target for labelled break/continue/fallthru in debug mode.
+	// Print branch target for labelled break/continue/fallthrough in debug mode.
 	if ( !options.genC && stmt->kind != ast::BranchStmt::Goto ) {
 		if ( !stmt->target.empty() ) {
